@@ -46,6 +46,8 @@ int stress_affinity(
 	const char *name)
 {
 	unsigned long int cpu = 0;
+	const unsigned long int cpus =
+		(unsigned long int)stress_get_processors_configured();
 	cpu_set_t mask;
 
 	(void)instance;
@@ -53,13 +55,16 @@ int stress_affinity(
 
 	do {
 		cpu = (opt_flags & OPT_FLAGS_AFFINITY_RAND) ?
-			(mwc() >> 4) : cpu + 1;
-		cpu %= stress_get_processors_online();
+			(mwc32() >> 4) : cpu + 1;
+		cpu %= cpus;
 		CPU_ZERO(&mask);
 		CPU_SET(cpu, &mask);
 		if (sched_setaffinity(0, sizeof(mask), &mask) < 0) {
 			pr_fail(stderr, "%s: failed to move to CPU %lu\n",
 				name, cpu);
+#if defined(_POSIX_PRIORITY_SCHEDULING)
+			sched_yield();
+#endif
 		} else {
 			/* Now get and check */
 			CPU_ZERO(&mask);
