@@ -88,6 +88,8 @@ again:
 			name, errno, strerror(errno));
 	} else if (pid > 0) {
 		int status, ret;
+
+		setpgid(pid, pgrp);
 		/* Parent, wait for child */
 		ret = waitpid(pid, &status, 0);
 		if (ret < 0) {
@@ -110,6 +112,8 @@ again:
 			}
 		}
 	} else if (pid == 0) {
+		setpgid(0, pgrp);
+
 		/* Make sure this is killable by OOM killer */
 		set_oom_adjustment(name, true);
 
