@@ -162,9 +162,11 @@ again:
 		return -1;
 	}
 	if (pid == 0) {
+		setpgid(0, pgrp);
 		func(child, counter, instance, max_ops, name, ppid);
 		exit(EXIT_SUCCESS);
 	}
+	setpgid(pid, pgrp);
 	return pid;
 }
 
@@ -187,9 +189,9 @@ static int epoll_set_fd_nonblock(const int fd)
  *  epoll_recv_data()
  *	receive data on fd
  */
-static void epoll_recv_data(const int fd) {
-
-	for (;;) {
+static void epoll_recv_data(const int fd)
+{
+	while (opt_do_run) {
 		char buf[8192];
 		ssize_t n;
 
@@ -283,7 +285,7 @@ static int epoll_client(
 	struct sigaction new_action;
 	struct sigevent sev;
 	struct itimerspec timer;
-	struct sockaddr *addr;
+	struct sockaddr *addr = NULL;
 
 	new_action.sa_flags = 0;
 	new_action.sa_handler = epoll_timer_handler;
@@ -377,8 +379,6 @@ retry:
 			goto retry;
 		}
 
-		retries = 0;
-
 		memset(buf, 'A' + (*counter % 26), sizeof(buf));
 		if (send(fd, buf, sizeof(buf), 0) < 0) {
 			(void)close(fd);
@@ -393,7 +393,7 @@ retry:
 	} while (opt_do_run && (!max_ops || *counter < max_ops));
 
 #ifdef AF_UNIX
-	if (opt_epoll_domain == AF_UNIX) {
+	if (addr && (opt_epoll_domain == AF_UNIX)) {
 		struct sockaddr_un *addr_un = (struct sockaddr_un *)addr;
 		(void)unlink(addr_un->sun_path);
 	}
@@ -422,7 +422,7 @@ static void epoll_server(
 	int port = opt_epoll_port + child + (max_servers * instance);
 	struct sigaction new_action;
 	struct epoll_event *events = NULL;
-	struct sockaddr *addr;
+	struct sockaddr *addr = NULL;
 	socklen_t addr_len = 0;
 
 	new_action.sa_handler = handle_socket_sigalrm;
@@ -530,7 +530,7 @@ die_close:
 		(void)close(sfd);
 die:
 #ifdef AF_UNIX
-	if (opt_epoll_domain == AF_UNIX) {
+	if (addr && (opt_epoll_domain == AF_UNIX)) {
 		struct sockaddr_un *addr_un = (struct sockaddr_un *)addr;
 		(void)unlink(addr_un->sun_path);
 	}
