@@ -76,7 +76,9 @@ again:
 		(void)close(fd2);
 		return EXIT_FAILURE;
 	} else if (pid == 0) {
-		for (;;) {
+		setpgid(0, pgrp);
+
+		while (opt_do_run) {
 			uint64_t val;
 			ssize_t ret;
 
