@@ -88,6 +88,8 @@ again:
 	if (pid > 0) {
 		int status;
 
+		setpgid(pid, pgrp);
+
 		do {
 			int ret;
 
@@ -108,6 +110,8 @@ again:
 
 		pr_dbg(stderr, "%s: futex timeouts: %" PRIu64 "\n", name, *timeout);
 	} else {
+		setpgid(0, pgrp);
+
 		do {
 			/* Small timeout to force rapid timer wakeups */
 			const struct timespec t = { .tv_sec = 0, .tv_nsec = 5000 };
@@ -122,14 +126,20 @@ again:
 			/* timeout, re-do, stress on stupid fast polling */
 			if ((ret < 0) && (errno == ETIMEDOUT)) {
 				(*timeout)++;
-				continue;
+				if (*timeout > 100000) {
+					pr_fail(stderr, "%s: futex wait, too "
+						"many timeouts: errno=%d (%s)\n",
+						name, errno, strerror(errno));
+					break;
+				}
+			} else {
+				if ((ret < 0) && (opt_flags & OPT_FLAGS_VERIFY)) {
+					pr_fail(stderr, "%s: futex wait "
+						"failed: errno=%d (%s)\n",
+						name, errno, strerror(errno));
+				}
+				(*counter)++;
 			}
-
-			if ((ret < 0) && (opt_flags & OPT_FLAGS_VERIFY)) {
-				pr_fail(stderr, "%s: futex wait failed: errno=%d (%s)\n",
-					name, errno, strerror(errno));
-			}
-			(*counter)++;
 		} while (opt_do_run && (!max_ops || *counter < max_ops));
 	}
 
