@@ -150,7 +150,7 @@ int stress_mmap(
 			return EXIT_FAILURE;
 
 		(void)stress_temp_filename(filename, sizeof(filename),
-			name, pid, instance, mwc());
+			name, pid, instance, mwc32());
 
 		(void)umask(0077);
 		if ((fd = open(filename, O_CREAT | O_RDWR, S_IRUSR | S_IWUSR)) < 0) {
@@ -224,14 +224,14 @@ redo:
 		 */
 		(void)mincore_touch_pages(buf, opt_mmap_bytes);
 		for (n = pages4k; n; ) {
-			uint64_t j, i = mwc() % pages4k;
+			uint64_t j, i = mwc64() % pages4k;
 			for (j = 0; j < n; j++) {
 				uint64_t page = (i + j) % pages4k;
 				if (mapped[page] == PAGE_MAPPED) {
 					mapped[page] = 0;
 					(void)madvise_random(mappings[page], page_size);
 					stress_mmap_mprotect(name, mappings[page], page_size);
-					munmap(mappings[page], page_size);
+					(void)munmap(mappings[page], page_size);
 					n--;
 					break;
 				}
@@ -239,13 +239,13 @@ redo:
 					goto cleanup;
 			}
 		}
-
+		(void)munmap(buf, sz);
 #ifdef MAP_FIXED
 		/*
 		 *  Step #2, map them back in random order
 		 */
 		for (n = pages4k; n; ) {
-			uint64_t j, i = mwc() % pages4k;
+			uint64_t j, i = mwc64() % pages4k;
 			for (j = 0; j < n; j++) {
 				uint64_t page = (i + j) % pages4k;
 				if (!mapped[page]) {
@@ -261,7 +261,7 @@ redo:
 						mapped[page] = PAGE_MAPPED_FAIL;
 						mappings[page] = NULL;
 					} else {
-						(void)mincore_touch_pages(buf, page_size);
+						(void)mincore_touch_pages(mappings[page], page_size);
 						(void)madvise_random(mappings[page], page_size);
 						stress_mmap_mprotect(name, mappings[page], page_size);
 						mapped[page] = PAGE_MAPPED;
@@ -293,7 +293,7 @@ cleanup:
 			if (mapped[n] & PAGE_MAPPED) {
 				(void)madvise_random(mappings[n], page_size);
 				stress_mmap_mprotect(name, mappings[n], page_size);
-				munmap(mappings[n], page_size);
+				(void)munmap(mappings[n], page_size);
 			}
 		}
 		(*counter)++;
