@@ -60,6 +60,8 @@ uint64_t opt_flags = PR_ERROR | PR_INFO | OPT_FLAGS_MMAP_MADVISE;
 volatile bool opt_do_run = true;		/* false to exit stressor */
 volatile bool opt_do_wait = true;		/* false to exit run waiter loop */
 volatile bool opt_sigint = false;		/* true if stopped by SIGINT */
+pid_t pgrp;					/* proceess group leader */
+
 
 /* Scheduler options */
 
@@ -91,13 +93,6 @@ static const int signals[] = {
 #ifdef SIGTERM
 	SIGTERM,
 #endif
-#ifdef SIGUSR1
-	SIGUSR1,
-#endif
-#ifdef SIGUSR2
-	SIGUSR2,
-	/* POSIX.1-2001 */
-#endif
 #ifdef SIGXCPU
 	SIGXCPU,
 #endif
@@ -1491,6 +1486,8 @@ static void kill_procs(const int sig)
 	if (count > 5)
 		signum = SIGKILL;
 
+	killpg(pgrp, sig);
+
 	for (i = 0; i < STRESS_MAX; i++) {
 		int j;
 
@@ -1680,6 +1677,7 @@ again:
 					goto wait_for_procs;
 				case 0:
 					/* Child */
+					setpgid(0, pgrp);
 					free_procs();
 					if (stress_sethandler(name, true) < 0)
 						exit(EXIT_FAILURE);
@@ -1734,6 +1732,7 @@ again:
 					exit(rc);
 				default:
 					if (pid > -1) {
+						setpgid(pid, pgrp);
 						procs[i].pids[j] = pid;
 						procs[i].started_procs++;
 					}
@@ -1753,7 +1752,8 @@ again:
 	(void)alarm(opt_timeout);
 
 abort:
-	pr_dbg(stderr, "%d stressors spawned\n", n_procs);
+	pr_dbg(stderr, "%d stressor%s spawned\n", n_procs,
+		n_procs == 1 ? "" : "s");
 
 wait_for_procs:
 	wait_procs(success);
@@ -1957,6 +1957,13 @@ int main(int argc, char **argv)
 	(void)stress_set_matrix_method("all");
 	(void)stress_set_vm_method("all");
 
+#if defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__NetBSD__)
+	setpgrp(0, 0);
+#else
+	setpgrp();
+#endif
+	pgrp = getpid();
+
 	if (stress_get_processors_configured() < 0) {
 		pr_err(stderr, "sysconf failed, number of cpus configured unknown: errno=%d: (%s)\n",
 			errno, strerror(errno));
@@ -2590,7 +2597,6 @@ next_opt:
 	}
 	memset(shared, 0, len);
 	pthread_spin_init(&shared->perf.lock, 0);
-	pthread_spin_init(&shared->sigsuspend.lock, 0);
 
 #if defined(STRESS_THERMAL_ZONES)
 	if (opt_flags & OPT_FLAGS_THERMAL_ZONES)
