@@ -368,6 +368,8 @@ extern void pr_yaml_runinfo(FILE *fp);
 #define MAX_SHM_SYSV_SEGMENTS	(128)
 #define DEFAULT_SHM_SYSV_SEGMENTS (8)
 
+#define MAX_SIGSUSPEND_PIDS	(4)
+
 #define MIN_SOCKET_PORT		(1024)
 #define MAX_SOCKET_PORT		(65535)
 #define DEFAULT_SOCKET_PORT	(5000)
@@ -645,9 +647,6 @@ typedef struct {
 		bool no_perf;				/* true = Perf not available */
 		pthread_spinlock_t lock;		/* spinlock on no_perf updates */
 	} perf;
-	struct {
-		pthread_spinlock_t lock;		/* spinlock on sigsuspend updates */
-	} sigsuspend;
 #if defined(STRESS_THERMAL_ZONES)
 	tz_info_t *tz_info;				/* List of valid thermal zones */
 #endif
@@ -814,7 +813,7 @@ typedef enum {
 #define STRESS_PROCFS __STRESS_PROCFS
 #endif
 	STRESS_PTHREAD,
-#if defined(__linux__)
+#if 0 && defined(__linux__)
 	__STRESS_PTRACE,
 #define STRESS_PTRACE __STRESS_PTRACE
 #endif
@@ -1535,6 +1534,7 @@ extern int32_t opt_sequential;		/* Number of sequential iterations */
 extern volatile bool opt_do_run;	/* false to exit stressor */
 extern volatile bool opt_sigint;	/* true if stopped by SIGINT */
 extern mwc_t __mwc;			/* internal mwc random state */
+extern pid_t pgrp;			/* proceess group leader */
 
 /*
  *  externs to force gcc to stash computed values and hence
