@@ -93,8 +93,9 @@ again:
 	} else if (pid == 0) {
 		int val = 0;
 
+		setpgid(0, pgrp);
 		(void)close(pipefds[1]);
-		for (;;) {
+		while (opt_do_run) {
 			char buf[PIPE_BUF];
 			ssize_t n;
 
@@ -106,7 +107,8 @@ again:
 					pr_failed_dbg(name, "read");
 					break;
 				}
-				continue;
+				pr_failed_dbg(name, "zero byte read");
+				break;
 			}
 			if (!strcmp(buf, PIPE_STOP))
 				break;
@@ -122,6 +124,7 @@ again:
 		int val = 0, status;
 
 		/* Parent */
+		setpgid(pid, pgrp);
 		(void)close(pipefds[0]);
 
 		do {
