@@ -180,9 +180,11 @@ again:
 		return -1;
 	}
 	if (pid == 0) {
+		setpgid(0, pgrp);
 		semaphore_sysv_thrash(name, max_ops, counter);
 		exit(EXIT_SUCCESS);
 	}
+	setpgid(pid, pgrp);
 	return pid;
 }
 
