@@ -40,7 +40,7 @@ static sigjmp_buf jmp_env;
  *  stress_segvhandler()
  *	SEGV handler
  */
-static void stress_segvhandler(int dummy)
+static void MLOCKED stress_segvhandler(int dummy)
 {
 	(void)dummy;
 
