@@ -103,12 +103,17 @@ again:
 		/* Child, client */
 		struct sockaddr *addr;
 
+		setpgid(0, pgrp);
 		do {
 			char buf[SOCKET_BUF];
 			int fd;
 			int retries = 0;
 			socklen_t addr_len = 0;
 retry:
+			if (!opt_do_run) {
+				(void)kill(getppid(), SIGALRM);
+				exit(EXIT_FAILURE);
+			}
 			if ((fd = socket(opt_socket_domain, SOCK_STREAM, 0)) < 0) {
 				pr_failed_dbg(name, "socket");
 				/* failed, kick parent to finish */
@@ -131,7 +136,6 @@ retry:
 				goto retry;
 			}
 
-			retries = 0;
 			do {
 				ssize_t n = recv(fd, buf, sizeof(buf), 0);
 				if (n == 0)
@@ -165,6 +169,8 @@ retry:
 		socklen_t addr_len = 0;
 		struct sockaddr *addr;
 
+		setpgid(pid, pgrp);
+
 		new_action.sa_handler = handle_socket_sigalrm;
 		sigemptyset(&new_action.sa_mask);
 		new_action.sa_flags = 0;
