@@ -1747,6 +1747,11 @@ static size_t stress_vm_rowhammer(
 	const size_t n = sz / sizeof(uint32_t);
 	register size_t j;
 
+	if (!n) {
+		pr_dbg(stderr, "rowhammer: zero uint32_t integers could be hammered, aborting\n");
+		return 0;
+	}
+
 	(void)mincore_touch_pages(buf, sz);
 
 	do {
@@ -1910,7 +1915,9 @@ again:
 			name, errno, strerror(errno));
 	} else if (pid > 0) {
 		int status, ret;
+
 		/* Parent, wait for child */
+		setpgid(pid, pgrp);
 		ret = waitpid(pid, &status, 0);
 		if (ret < 0) {
 			if (errno != EINTR)
@@ -1931,6 +1938,8 @@ again:
 			}
 		}
 	} else if (pid == 0) {
+		setpgid(0, pgrp);
+
 		/* Make sure this is killable by OOM killer */
 		set_oom_adjustment(name, true);
 
