@@ -169,16 +169,16 @@ void tz_dump(
 
 	for (i = 0; i < STRESS_MAX; i++) {
 		tz_info_t *tz_info;
-		int32_t  j, n = (i * max_procs);
+		int32_t  j;
 		uint64_t total = 0;
 		uint32_t count = 0;
 		bool dumped_heading = false;
 
 		for (tz_info = shared->tz_info; tz_info; tz_info = tz_info->next) {
-			for (j = 0; j < procs[i].started_procs; j++, n++) {
+			for (j = 0; j < procs[i].started_procs; j++) {
 				uint64_t temp;
+				int32_t n = (i * max_procs) + j;
 
-				n = (i * max_procs) + j;
 				temp = shared->stats[n].tz.tz_stat[tz_info->index].temperature;
 				/* Avoid crazy temperatures. e.g. > 250 C */
 				if (temp > 250000)
